@@ -6,7 +6,7 @@
 # Written by Carter T. Butts <buttsc@uci.edu>
 # Last Modified 9/6/10
 # Licensed under the GNU General Public License version 2 (June, 1991)
-# or later
+# or greater
 #
 # Part of the R/network package
 #
